from bkn_xi_dms.utill.installed_application import *
import pandas as pd
import os
import openpyxl
from openpyxl.utils.dataframe import dataframe_to_rows


def create_report(json):
    return {
        "job_id": json["data"]["uniqueCode"],
        "qty": json["data"]["documentQty"],
        "tanggal":  json["data"]["createdDate"]
    }


def create_report_excel(list_data, output_path, sheet, color):
    list_data = pd.DataFrame(list_data)
    if os.path.isfile(output_path):
        workbook = openpyxl.load_workbook(output_path)
        if sheet in workbook.sheetnames:
            existing_data = pd.read_excel(output_path, sheet_name=sheet)
            updated_data = pd.concat([existing_data, list_data])
            worksheet = workbook[sheet]
            worksheet.sheet_properties.tabColor = color
            for row in dataframe_to_rows(updated_data, index=False, header=False):
                worksheet.append(row)
            workbook.save(output_path)
        else:
            worksheet = workbook.create_sheet(title=sheet)
            worksheet.sheet_properties.tabColor = color
            for row in dataframe_to_rows(list_data, index=False, header=True):
                worksheet.append(row)
        workbook.save(output_path)
    else:
        workbook = openpyxl.Workbook()
        worksheet = workbook.active
        worksheet.title = sheet
        worksheet.sheet_properties.tabColor = color
        for row in dataframe_to_rows(list_data, index=False, header=True):
            worksheet.append(row)
        workbook.save(output_path)



import requests
from requests.packages import urllib3


def set_upload_document(id, path, link_upload_document, headers_upload):
    urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)

    post_url = link_upload_document
    files = {'RemoteFile': open(path, 'rb')}

    payload = {
        "id": id
    }

    resp = requests.post(post_url, headers=headers_upload, files=files,
                         data=payload, verify=False)
    # print("====================================")
    # print("respon uploaded adalah", resp.content)



# turn document name from : nama dokument_nip to nama_dokument

import os
from datetime import date
import PyPDF2
from os import path


path_directory = "c:\\dmsUploadExperiment2\\"
list_employee_nip = os.listdir(path_directory)

separator = "_"

for folder in list_employee_nip:
    list_doc = os.listdir(path_directory + folder)
    base_path = os.path.join(path_directory + folder)
    for filename in list_doc:
        old_file_path = os.path.join(base_path, filename)
        new_filename = filename.split(
            separator)[0] + os.path.splitext(filename)[1]
        new_file_path = os.path.join(base_path, new_filename)
        print(new_file_path)
        os.rename(old_file_path, new_file_path)



from requests.packages import urllib3
import requests


class SearchEmployee:
    def __init__(self):
        print("executed SearchEmployee")

    class Employee:
        nip_baru = ""
        nama = ""
        key_cloack_id = ""

    def search_by_nip(self, id, headers, link_search_nip):
        urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)

        url_get_pegawai = link_search_nip+id
        res_search = requests.get(
            url=url_get_pegawai, headers=headers, verify=False)
        if (res_search.status_code) == 200:
            employee = self.Employee()
            rs_json = res_search.json()
            employee.nip_baru = rs_json['data']['nipBaru']
            employee.nama = rs_json['data']['nama']
            employee.key_cloack_id = rs_json['data']['keycloackId']
            return employee
        else:
            return None





"""
created on Wed Feb 2023

"""
import re


def get_jenis_file(file_name, list_document_type):
    id = ""
    for keyval in list_document_type:
        name = keyval["name"]
        if re.search(name.lower(), file_name.lower()):
            id = keyval["id"]
            break
        else:
            id = 0
    return id



import shutil
import os

# Path of the file to be moved
with open('', 'r') as f:
    my_list = [line.strip() for line in f.readlines()]

list_item = []
list_file_name = []
for item in my_list:
    folder_name = item.split('\\')
    list_item.append(folder_name[-2])

for item in list_item:
    filename, extension = os.path.splitext(item)
    list_file_name.append(filename)
print(list_file_name)



import json
import requests
import os
import shutil
from datetime import date
from os import path
from requests.packages import urllib3


def add_document(headers, employee, document, job_id, link_create_document):
    url_create_document = link_create_document
    item = {
        "documentTypeId": document["document_id"],
        "documentDate": date.today().strftime("%d/%m/%Y"),
        "retention": True,
        "isRetention": 1,
        "retentionPeriodId": 20,
        "retentionInterval": 2,
        "pagesQty": document["document_page_qty"],
        "nip": employee["nip"],
        "oldNip": "",
        "profileNik": "",
        "profileFullname": employee["name"],
        "profileInstance": "",
        "profileClass": "",
        "profileId": "",
        "jobScanId": job_id
    }
    resp = requests.post(url_create_document, headers=headers,
                         json=item, verify=False)

    if (resp.status_code == 201):
        resp = resp.json()
        document = {
            "id":  resp["data"]["id"],
            "path": document["document_path"]
        }
        return document



import winreg


def is_excel_installed():
    reg_path = r"SOFTWARE\Microsoft\Windows\CurrentVersion\App Paths\excel.exe"
    try:
        with winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE, reg_path) as key:
            value, _ = winreg.QueryValueEx(key, None)
            return True
    except:
        return False




import os
from datetime import date
import PyPDF2
from os import path
from .search_employee import *
from .jenis_dokumen import *


path_directory = ""
list_employee_nip = os.listdir(path_directory)

name_mapping = {"old_filename_1.txt": "Surat Tanda Tamat Belajar.pdf",
                "old_filename_2.txt": "Transkrip Nilai.pdf",
                "old_filename_1.txt": "Daftar Riwayat Hidup.pdf",
                "old_filename_1.txt": "Pertimbangan Teknis Penetapan NIP.pdf",
                }

for folder in list_employee_nip:
    list_doc = os.listdir(path_directory + employee_nip)
    for filename in list_doc:
        if filename in name_mapping:
            old_file_path = os.path.join(list_doc, filename)
            new_filename = name_mapping[filename]
            new_file_path = os.path.join(directory, new_filename)
            os.rename(old_file_path, new_file_path)



import os
from datetime import date
import PyPDF2
from os import path
from .search_employee import *
from .jenis_dokumen import *
from .report.prascan import *


def get_document_total_page(path_document):
    file = open(path_document, 'rb')

    # baca jumlah halaman
    readpdf = PyPDF2.PdfReader(file)
    totalpages = len(readpdf.pages)
    # tutup koneksi ke file
    file.close()
    return totalpages


def to_text(list, path):
    if os.path.exists(path) and os.path.getsize(path) > 0:
        with open(path, 'a') as f:
            f.write('\n'.join(list))
    else:
        with open(path, 'w') as f:
            f.write('\n'.join(list))

    print("done file at the", path)


def create_list_employee_document_by_directory(path_directory, headers, path_report_file, link_search_nip, list_document_type):

    list_employees_not_found = []
    list_documents_not_pdf = []
    list_documents_over_limit_size = []
    list_document_will_upload = []
    list_employee_nip = os.listdir(path_directory)
    list_document_job = []
    list_job = []
    list_file_not_upload = []
    for employee_nip in list_employee_nip:
        count = 0
        limit = 10
        employee = SearchEmployee()
        if employee.search_by_nip(employee_nip, headers, link_search_nip) is None:
            print("Employee Tidak Ditemukan")
            list_employees_not_found.append({"nip": employee_nip})
            continue
        list_doc = os.listdir(path_directory + employee_nip)
        base_path = os.path.join(path_directory + employee_nip)

        employee_doc = {
            "nip": employee_nip,
            "name": employee.search_by_nip(employee_nip, headers, link_search_nip).nama,
            "job_scan_id": "",
            "document": []
        }

        status = 0
        for item in list_doc:
            document_path = os.path.join(base_path, item)
            if not os.path.isfile(document_path):
                continue
            elif not document_path.endswith(".pdf"):
                list_documents_not_pdf.append(
                    {"NIP": employee_nip, "PATH": document_path})
                continue
            if os.path.getsize(document_path) > 10*1024*1000:
                list_documents_over_limit_size.append(
                    {"NIP": employee_nip, "PATH": document_path})
                continue
            document_name = item
            document_type = item.rsplit('.', 1)[0]
            document_path = os.path.join(base_path, item)
            document_page_qty = get_document_total_page(document_path)
            if count < limit:
                document = {
                    "document_id": get_jenis_file(document_name, list_document_type),
                    "document_name": document_name,
                    "document_type": document_type,
                    "document_path": document_path,
                    "document_page_qty": document_page_qty,
                    "document_date": date.today().strftime("%d/%m/%Y"),
                    "document_job_scan_id": ""
                }
                if document["document_id"] == 0:
                    list_file_not_upload.append(document_path)
                    continue
# Add Filtered Document Upload
                list_document_will_upload.append(
                    {"nip": employee_nip, "path": document_path})
                employee_doc["document"].append(document)
                count += 1
                if count == limit:
                    list_document_job.append(employee_doc)
                    status = 1
            else:
                limit += 10
                employee_doc = {
                    "nip": employee_nip,
                    "name": employee.search_by_nip(employee_nip, headers, link_search_nip).nama,
                    "job_scan_id": "",
                    "document": []
                }
                document = {
                    "document_id": get_jenis_file(document_name, list_document_type),
                    "document_name": document_name,
                    "document_type": document_type,
                    "document_path": document_path,
                    "document_page_qty": document_page_qty,
                    "document_date": date.today().strftime("%d/%m/%Y"),
                    "document_job_scan_id": ""
                }
                if document["document_id"] == 0:
                    list_file_not_upload.append(document_path)
                    continue
# Add Filtered Document Upload
                list_document_will_upload.append(
                    {"nip": employee_nip, "path": document_path})
                employee_doc["document"].append(document)
                count += 1
                status = 0
        if status == 0:
            list_document_job.append(employee_doc)

    if len(list_employees_not_found) != 0:
        create_report_excel(list_employees_not_found,
                            path_report_file, "NIP_Tidak_Ditemukan", "ffff0000")
    if len(list_documents_not_pdf) != 0:
        create_report_excel(list_documents_not_pdf,
                            path_report_file, "Bukan_PDF", "ffff0000")
    if len(list_documents_over_limit_size) != 0:
        create_report_excel(list_documents_over_limit_size,
                            path_report_file, "File_Besar", "ffff0000")
    if len(list_file_not_upload) != 0:
        create_report_excel(list_file_not_upload,
                            path_report_file, "File_miss", "ffff0000")
    if len(list_document_will_upload) != 0:
        create_report_excel(list_document_will_upload,
                            path_report_file, "Draft File Upload", "ff00ff00")
    return list_document_job



import json
import requests


def createJobScan(headers, link_create_job):
    url_create_job = link_create_job

    jsonc = {
        "createdById": "null",
        "createdDate": "null",
        "documentQty": 0,
        "id": "null",
        "remarks": "",
        "runnerName": "null",
        "runnerNip": "null",
        "status": "null",
        "uniqueCode": "null",
        "updateDate": "null"
    }
    resp = requests.post(url_create_job, headers=headers,
                         json=jsonc, verify=False)
    if (resp.status_code == 201):
        return resp.json()
    else:
        print("!!!!!!!!!!!!!!!!error create Job!!!!!!!!!!!!!!!!!!!!")
        print("!!!!!!!!!!!!!!!!error create Job!!!!!!!!!!!!!!!!!!!!")
        print(resp.json())
        return resp.json()



import re
import os
text = "The quick brown fox jumps over the lazy dog"
# pattern = "2_IJAZAH SD_197212051999112001_1985.pdf"

# Use the search() function to find the first occurrence of the pattern in the text

# for keyval in list_jenis_dokument:
#     name = keyval["name"]
#     match = re.search(name.lower(), pattern.lower())

#     if match:
#         print(keyval["id"])
#         print(keyval["name"])
#     else:
#         print("Pattern not found")
#         doc = 0

# for keyval in list_jenis_dokument:
#     name = keyval["name"]
#     match = re.search(pattern.lower(), name.lower())
#     if match:
#         print(keyval["id"])
#         print(keyval["name"])
#     else:
#         print("Pattern not found")

list_jenis_dokument = []


def to_text(list, path):
    with open(path, 'w') as f:
        f.write('\n'.join(list))
        # pickle.dump(list, f)

    print("done file at the", path)


path_write = "C:\\Users\\Rifo\\Desktop\\output2.txt"
path_directory = "c:\\dmsUploadExperiment\\"

list_folder = os.listdir(path_directory)
list_files = []
for folder in list_folder:
    path_folder = os.path.join(path_directory + folder)
    list_document = os.listdir(path_directory + folder)

    for document in list_document:
        doc = 1
        for keyval in list_jenis_dokument:
            name = keyval["name"]

            if (re.search(name.lower(), document.lower())):
                print(name.lower() + "-" + document.lower())
                doc = 0
        if doc == 1:
            list_files.append(os.path.join(
                path_directory + folder + "\\" + document))
to_text(list_files, path_write)



from setuptools import setup, find_packages

VERSION = '1.0.3'
DESCRIPTION = 'Document Management System (DMS) Assistan'
LONG_DESCRIPTION = 'A package that allows to Automation a process in DMS to spesific upload document'

# Setting up
setup(
    name="bkn_xi_dms",
    version=VERSION,
    author="Rifo Pangemanan (ifodigital)",
    author_email="<rifopangemanan@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=['pandas', 'openpyxl', 'PyPDF2'],
    keywords=['BKN'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)



# scan all file if there any not in mapping name will be write in text document
import os
import pickle


def to_text(list, path):
    with open(path, 'w') as f:
        f.write('\n'.join(list))
        # pickle.dump(list, f)

    print("done file at the", path)


path = "C:\\Users\\Rifo\\Desktop\\output.txt"
path_from = "c:\\dmsUploadExperiment2\\"

list_employee_nip = os.listdir(path_from)
list_files = []

name_mapping = {"Surat Tanda Tamat Belajar.pdf": "Surat Tanda Tamat Belajar.pdf",
                "old_filename_2.txt": "Transkrip Nilai.pdf",
                "old_filename_1.txt": "Daftar Riwayat Hidup.pdf",
                "old_filename_1.txt": "Pertimbangan Teknis Penetapan NIP.pdf",
                }

for folder in list_employee_nip:
    list_doc = os.listdir(path_from + folder)
    for filename in list_doc:
        if filename not in name_mapping:
            # item_file = {
            #     "nama": filename,
            #     "path":  os.path.join(path_from + folder)
            # }
            # list_files.append(item_file)
            list_files.append(os.path.join(
                path_from + folder + "\\" + filename))
to_text(list_files, path)
